@@ -16,10 +16,10 @@ from typing import List, Optional, NoReturn
 import pygame
 from pygame.constants import *
 
-from _widget_bases import IWidget, IWidgetInterface
-from colors import BLACK
-from multitouch.raspberrypi_ts import Touchscreen, TS_RELEASE
 from pi_touch_gui._utilities import backlog_error
+from pi_touch_gui._widget_bases import IWidget, IWidgetInterface
+from pi_touch_gui.colors import BLACK
+from pi_touch_gui.multitouch.raspberrypi_ts import Touchscreen, TS_RELEASE
 
 LOG = logging.getLogger(__name__)
 
